==> cbra-0.19.1.tar.gz: cbra-0.19.1/cbra/tests/conftest.py <==
# pylint: skip-file
import unittest.mock

import aorta
import fastapi
import ioc
import pytest
import pytest_asyncio
from httpx import AsyncClient

import cbra


class TestSubresource(cbra.PublicResource):
    path_parameter: int = 'child_id'
    name = 'sub'

    async def list(self, object_id: str):
        return {'object_id': object_id}

    async def retrieve(self, object_id: str, child_id: int):
        return {'object_id': object_id, 'child_id': child_id}


class TestResource(cbra.PublicResource):
    path_parameter: str = 'object_id'
    name = 'example'
    subresources = [TestSubresource]

    async def create(self, dto: dict):
        return {'dto': dto}

    async def list(self):
        return []

    async def destroy(self, object_id: str):
        return {'object_id': object_id}

    async def exists(self, object_id: str):
        return {'object_id': object_id}

    async def receive(self, object_id: str, dto: dict):
        return {'object_id': object_id, 'dto': dto}

    async def replace(self, object_id: str, dto: dict):
        return {'object_id': object_id, 'dto': dto}

    async def retrieve(self, object_id: str):
        return {'object_id': object_id}

    async def update(self, object_id: str, dto: dict):
        return {'object_id': object_id, 'dto': dto}


class TestProtectedResource(cbra.Resource):
    path_parameter: str = 'object_id'
    name = 'protected'

    async def retrieve(self, object_id: str):
        return {'object_id': object_id, 'principal': self.principal}


class TestCommand(aorta.Command):
    foo: int


class TestEvent(aorta.Event):
    foo: int


@pytest.fixture
def app():
    app = fastapi.FastAPI()
    TestResource.add_to_router(app, '')
    TestProtectedResource.add_to_router(app, '')
    return app


@pytest_asyncio.fixture
async def client(app):
    async with AsyncClient(app=app, base_url="http://test") as client:
        yield client


@pytest.fixture
def transport():
    t = aorta.transport.NullTransport()
    t.send = unittest.mock.AsyncMock()
    pub = aorta.MessagePublisher(transport=t)
    ioc.provide('MessagePublisher', pub, force=True)
    return t


@pytest.fixture
def command():
    return TestCommand(foo=1)


@pytest.fixture
def event():
    return TestEvent(foo=1)

==> cbra-0.50.0.tar.gz: cbra-0.50.0/cbra/tests/conftest.py <==
# pylint: skip-file
import functools
import unittest.mock

import aorta
import fastapi
import pytest
import pytest_asyncio
from httpx import AsyncClient

import cbra
from cbra.ext import ioc


class TestSubresource(cbra.PublicResource):

    class Meta:
        path_parameter: int = 'child_id'
        name = 'sub'

    async def list(self, object_id: str):
        return {'object_id': object_id}

    async def retrieve(self, object_id: str, child_id: int):
        return {'object_id': object_id, 'child_id': child_id}


class TestResource(cbra.PublicResource):
    subresources = [TestSubresource]

    class Meta:
        path_parameter: str = 'object_id'
        name = 'example'

    async def create(self, dto: dict):
        return {'dto': dto}

    async def list(self):
        return []

    async def destroy(self, object_id: str):
        return {'object_id': object_id}

    async def exists(self, object_id: str):
        return {'object_id': object_id}

    async def receive(self, object_id: str, dto: dict):
        return {'object_id': object_id, 'dto': dto}

    async def replace(self, object_id: str, dto: dict):
        return {'object_id': object_id, 'dto': dto}

    async def retrieve(self, object_id: str):
        return {'object_id': object_id}

    async def update(self, object_id: str, dto: dict):
        return {'object_id': object_id, 'dto': dto}


class TestProtectedResource(cbra.Resource):

    class Meta:
        path_parameter: str = 'object_id'
        name = 'protected'

    async def retrieve(self, object_id: str):
        return {'object_id': object_id, 'principal': self.principal}


class TestCommand(aorta.Command):
    foo: int


class TestEvent(aorta.Event):
    foo: int


@pytest.fixture
def app():
    app = fastapi.FastAPI(
        docs_url='/ui',
    )
    TestResource.add_to_router(app, '')
    TestProtectedResource.add_to_router(app, '')
    return app


@pytest.fixture
def transport():
    t = aorta.transport.NullTransport()
    t.send = unittest.mock.AsyncMock()
    pub = aorta.MessagePublisher(transport=t)
    ioc.provide('MessagePublisher', pub, force=True)
    return t


@pytest.fixture
def command():
    return TestCommand(foo=1)


@pytest.fixture
def event():
    return TestEvent(foo=1)
